# CHANGELOG



## v0.1.2 (2024-04-14)

### Fix

* fix: adding data files ([`480429d`](https://github.com/gasflux/gasflux/commit/480429d72519d6a53262e4ebbe480548a9162a37))


## v0.1.1 (2024-04-14)

### Chore

* chore: bump requirements ([`9031363`](https://github.com/gasflux/gasflux/commit/90313637df28fb32fd97968fe2b84db68235ba12))

* chore: update gitignore ([`cf53b4b`](https://github.com/gasflux/gasflux/commit/cf53b4b2ba15a80c95b97e2552c96a13d6a80afb))

### Documentation

* docs: update readme ([`fd3ddf0`](https://github.com/gasflux/gasflux/commit/fd3ddf0fd9ff8a3d43e68636bb3bb54292a02e32))

* docs: Update README.md ([`7c6b145`](https://github.com/gasflux/gasflux/commit/7c6b1450d87262bcf8f92d6285347c0b4b362872))

* docs: update reademe ([`dd05004`](https://github.com/gasflux/gasflux/commit/dd050040990648a33d3454cb0627f71696de1603))

* docs: readme and variable names ([`308f305`](https://github.com/gasflux/gasflux/commit/308f305ef075d3d87ca60bcebf1c4a51e851604b))

### Feature

* feat: add version number to outputs ([`0b78052`](https://github.com/gasflux/gasflux/commit/0b78052c855e5bf08faa69ba80e512c100a4c833))

* feat: remove long arrays from output ([`afe1617`](https://github.com/gasflux/gasflux/commit/afe1617401bb0a3f27900347642c80f969c4d504))

* feat: adding output dump ([`7fa52e8`](https://github.com/gasflux/gasflux/commit/7fa52e861db1877fc1f57073aa0e796338b63e68))

* feat: better CLI ([`9918e48`](https://github.com/gasflux/gasflux/commit/9918e4822b9f1fa4be702b82a4850d04824e0b12))

* feat: cli add ([`f018d1d`](https://github.com/gasflux/gasflux/commit/f018d1d761ae92c5e6c9f6f729bac4b57f7b7573))

### Fix

* fix: add debug access ([`a842940`](https://github.com/gasflux/gasflux/commit/a84294001f22ab83915444c13d040adadb0fc777))

### Refactor

* refactor: baseline -&gt; background ([`4cbd245`](https://github.com/gasflux/gasflux/commit/4cbd2453b65f6d1c9cf53e80ce0e1eed535b7930))

### Test

* test: config output == input ([`ae55a97`](https://github.com/gasflux/gasflux/commit/ae55a9732ab509b7b06c6701439ae55be53ffedf))

* test: update for logging field ([`279f5bb`](https://github.com/gasflux/gasflux/commit/279f5bbc068576771af9381e048a0fb3837d8fe9))

### Unknown

* Update pyproject.toml ([`ee79814`](https://github.com/gasflux/gasflux/commit/ee798149660c07c05e3f64ba2c5ca1ac8340a11d))

* pypi (#40)

* build: twine &amp; pypi

* test: change dir structure ([`7652335`](https://github.com/gasflux/gasflux/commit/76523356960978178e6e61955567bdcce12c2820))

* badges ([`aa0002a`](https://github.com/gasflux/gasflux/commit/aa0002ae6aacf67005d2131d7b61e9a3bfe7f9f8))

* class update (#35)

* refactor: pipelines to strategy pattern

* test: update col ([`6980473`](https://github.com/gasflux/gasflux/commit/69804739104e306d511b209d3b2c4e78c3a7bfad))

* better wind handling (#34) ([`ddf2e01`](https://github.com/gasflux/gasflux/commit/ddf2e017fcaeae852491ac086aca91a48cbbc228))

* Update LICENSE ([`347ade3`](https://github.com/gasflux/gasflux/commit/347ade3e4970869bf094bd52e44f423dfe74d790))

* tests (#32)

* remove [slice]

* dtypes

* config

* edge_effects

* test updates

* tests

* version

* reqs ([`9b67a25`](https://github.com/gasflux/gasflux/commit/9b67a25afafbf1c348e144a33de1ca0e0d65145c))

* Update CI.yml ([`16efe4e`](https://github.com/gasflux/gasflux/commit/16efe4ed16552534224b3254dfda5941bd81e6cd))

* Update CI.yml ([`b429b33`](https://github.com/gasflux/gasflux/commit/b429b335dee9f5553b32377fc7b6bd43bd777164))

* Update CI.yml ([`8ac18e7`](https://github.com/gasflux/gasflux/commit/8ac18e781a6075bad83b82caabe4470139b5c202))

* Update CI.yml ([`1b39aaa`](https://github.com/gasflux/gasflux/commit/1b39aaa69026375aa6f735d5e996589176d93e7a))

* Update CI.yml ([`ba41024`](https://github.com/gasflux/gasflux/commit/ba41024adfb14d878d1c1be5a16218d88c64f4ac))

* Create python-semantic-release.yml ([`026383f`](https://github.com/gasflux/gasflux/commit/026383f62b98505742051fa83cc3f3e1c016c26a))

* data generation (#27)

* test data generation

* better testdata gen ([`949f4a5`](https://github.com/gasflux/gasflux/commit/949f4a511a1b10fbd481a03c45371e50220705a2))

* linting (#25)

* linting and docstrings

* remove matplotlib

* tidy

* ruff formatting

* linting

* docstrings &amp; linting

* Update CI.yml

* add ci auto config ([`14b238e`](https://github.com/gasflux/gasflux/commit/14b238edc34d77680087afac957b4d0a6b398812))

* squash ([`e9ac732`](https://github.com/gasflux/gasflux/commit/e9ac7326b018d1846df550f77e5be1c257271aae))

* remove tests until they are written ([`cb9f787`](https://github.com/gasflux/gasflux/commit/cb9f787ef619a8f4c8f0fbf6c11bc476252fae51))

* bump dev-requirements ([`c1380d8`](https://github.com/gasflux/gasflux/commit/c1380d8fc031dda66cee1d248796f27cf251135e))

* Update and rename blank.yml to CI.yml ([`20da613`](https://github.com/gasflux/gasflux/commit/20da613166013f80ced32810603d8054a7fdb43f))

* bump dev-requirements ([`89841b7`](https://github.com/gasflux/gasflux/commit/89841b799e17719bc4a029e481da917c3a628b83))

* bump requirements ([`cf201b5`](https://github.com/gasflux/gasflux/commit/cf201b5ae65fc46e48a0dce3538d324b58b2941c))

* first commit - add flux.py and various linting/setup files ([`a9838f9`](https://github.com/gasflux/gasflux/commit/a9838f91cafe31cfef1c145ce00a86f3dbad7d3b))

* Create CI ([`2a400bd`](https://github.com/gasflux/gasflux/commit/2a400bddfcd5f17786e74752a2ab5013df047e4b))

* add .gitignore ([`3e3cdc7`](https://github.com/gasflux/gasflux/commit/3e3cdc7ba447690f6a046d6b5baa236fc85f3d36))

* Initial commit ([`6329c9e`](https://github.com/gasflux/gasflux/commit/6329c9e6ace8f076877b86cb4e28884eb58d5e40))
